==> spring-expression-4.1.1.RELEASE-sources.jar: org/springframework/expression/spel/ast/FloatLiteral.java <==
/*
 * Copyright 2002-2014 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.springframework.expression.spel.ast;

import org.springframework.asm.MethodVisitor;
import org.springframework.expression.TypedValue;
import org.springframework.expression.spel.CodeFlow;

/**
 * Expression language AST node that represents a float literal.
 *
 * @author Satyapal Reddy
 * @author Andy Clement
 * @since 3.2
 */
public class FloatLiteral extends Literal {

	private final TypedValue value;

	FloatLiteral(String payload, int pos, float value) {
		super(payload, pos);
		this.value = new TypedValue(value);
		this.exitTypeDescriptor = "F";
	}


	@Override
	public TypedValue getLiteralValue() {
		return this.value;
	}

	@Override
	public boolean isCompilable() {
		return true;
	}
	
	@Override
	public void generateCode(MethodVisitor mv, CodeFlow codeflow) {
		mv.visitLdcInsn(this.value.getValue());
		codeflow.pushDescriptor(getExitDescriptor());
	}
}

==> spring-expression-5.1.0.RELEASE-sources.jar: org/springframework/expression/spel/ast/FloatLiteral.java <==
/*
 * Copyright 2002-2018 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.springframework.expression.spel.ast;

import org.springframework.asm.MethodVisitor;
import org.springframework.expression.TypedValue;
import org.springframework.expression.spel.CodeFlow;

/**
 * Expression language AST node that represents a float literal.
 *
 * @author Satyapal Reddy
 * @author Andy Clement
 * @since 3.2
 */
public class FloatLiteral extends Literal {

	private final TypedValue value;


	public FloatLiteral(String payload, int pos, float value) {
		super(payload, pos);
		this.value = new TypedValue(value);
		this.exitTypeDescriptor = "F";
	}


	@Override
	public TypedValue getLiteralValue() {
		return this.value;
	}

	@Override
	public boolean isCompilable() {
		return true;
	}

	@Override
	public void generateCode(MethodVisitor mv, CodeFlow cf) {
		mv.visitLdcInsn(this.value.getValue());
		cf.pushDescriptor(this.exitTypeDescriptor);
	}

}
